Mopidy-InternetArchive
========================================================================

Mopidy-InternetArchive is a Mopidy_ extension for playing music and
audio from the `Internet Archive`_.


Installation
------------------------------------------------------------------------

Mopidy-InternetArchive can be installed using pip_ by running::

    pip install Mopidy-InternetArchive


Project Resources
------------------------------------------------------------------------

.. image:: https://img.shields.io/pypi/v/Mopidy-InternetArchive.svg?style=flat
    :target: https://pypi.python.org/pypi/Mopidy-InternetArchive/
    :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/Mopidy-InternetArchive.svg?style=flat
    :target: https://pypi.python.org/pypi/Mopidy-InternetArchive/
    :alt: Number of PyPI downloads

.. image:: https://readthedocs.org/projects/mopidy-internetarchive/badge/?version=latest&style=flat
   :target: https://readthedocs.org/projects/mopidy-internetarchive/?badge=latest
   :alt: Documentation Status

- `Documentation`_
- `Issue Tracker`_
- `Source Code`_
- `Change Log`_


License
------------------------------------------------------------------------

Copyright (c) 2014 Thomas Kemmer.

Licensed under the `Apache License, Version 2.0`_.


.. _Mopidy: http://www.mopidy.com/
.. _Internet Archive: http://archive.org/

.. _pip: https://pip.pypa.io/en/latest/

.. _Documentation: http://mopidy-internetarchive.readthedocs.org/en/latest/
.. _Issue Tracker: https://github.com/tkem/mopidy-internetarchive/issues/
.. _Source Code: https://github.com/tkem/mopidy-internetarchive/
.. _Change Log: https://raw.github.com/tkem/mopidy-internetarchive/master/Changes

.. _Apache License, Version 2.0: http://www.apache.org/licenses/LICENSE-2.0
